==> haskell-half-0.3-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-half.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: half
version: 0.3
id: half-0.3-FAYfwVspNsbBCdMMJ4crrU
key: half-0.3-FAYfwVspNsbBCdMMJ4crrU
license: BSD-3-Clause
copyright: Copyright (C) 2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/half
synopsis: Half-precision floating-point
description:
    Half-precision floating-point.
category: Numeric
abi: 870dc01ee4ce7c80d4551f1e6acfcbd8
exposed: True
exposed-modules:
    Numeric.Half
import-dirs: /usr/lib/ghc-8.4.3/site-local/half-0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/half-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/half-0.3
hs-libraries: HShalf-0.3-FAYfwVspNsbBCdMMJ4crrU
depends:
    base-4.11.1.0 template-haskell-2.13.0.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-half/html/half.haddock
haddock-html: /usr/share/doc/haskell-half/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-half-0.3-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-half.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: half
version: 0.3
id: half-0.3-CH64UkX5I38VGgO59giab
key: half-0.3-CH64UkX5I38VGgO59giab
license: BSD-3-Clause
copyright: Copyright (C) 2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/half
synopsis: Half-precision floating-point
description:
    Half-precision floating-point.
category: Numeric
abi: 6ac643b9d82de97ade032440ee7b71cd
exposed: True
exposed-modules:
    Numeric.Half
import-dirs: /usr/lib/ghc-8.4.3/site-local/half-0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/half-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/half-0.3
hs-libraries: HShalf-0.3-CH64UkX5I38VGgO59giab
depends:
    base-4.11.1.0 template-haskell-2.13.0.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-half/html/half.haddock
haddock-html: /usr/share/doc/haskell-half/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
